pub trait IntoHex {
// Required method
fn to_hex(&self) -> String;
// Provided method
fn into_hex(self) -> String
where Self: Sized { ... }
}Expand description
Type implementing this trait can be encoded into a hex string.
pub trait IntoHex {
// Required method
fn to_hex(&self) -> String;
// Provided method
fn into_hex(self) -> String
where Self: Sized { ... }
}Type implementing this trait can be encoded into a hex string.